@@ -2,11 +2,11 @@
 
 config() {
   NEW="$1"
-  OLD="`dirname $NEW`/`basename $NEW .new`"
+  OLD="$(dirname $NEW)/$(basename $NEW .new)"
   # If there's no config file by that name, mv it over:
   if [ ! -r $OLD ]; then
     mv $NEW $OLD
-  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
+  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
     # toss the redundant copy
     rm $NEW
   fi
@@ -25,13 +25,19 @@ config etc/dbus-1/system.d/hal.conf.new
 
 ( cd usr/lib ; rm -rf libhal.so.1 )
 ( cd usr/lib ; ln -sf libhal.so.1.0.0 libhal.so.1 )
+( cd usr/lib/hal/scripts/linux ; rm -rf hal-system-wol-enable-linux )
+( cd usr/lib/hal/scripts/linux ; ln -sf hal-system-wol-linux hal-system-wol-enable-linux )
+( cd usr/lib/hal/scripts/linux ; rm -rf hal-system-wol-supported-linux )
+( cd usr/lib/hal/scripts/linux ; ln -sf hal-system-wol-linux hal-system-wol-supported-linux )
+( cd usr/lib/hal/scripts/linux ; rm -rf hal-system-wol-enabled-linux )
+( cd usr/lib/hal/scripts/linux ; ln -sf hal-system-wol-linux hal-system-wol-enabled-linux )
 ( cd usr/lib ; rm -rf libhal.so )
 ( cd usr/lib ; ln -sf libhal.so.1.0.0 libhal.so )
 ( cd usr/lib ; rm -rf libhal-storage.so.1 )
 ( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so.1 )
 ( cd usr/lib ; rm -rf libhal-storage.so )
 ( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so )
-( cd usr/doc/hal-0.5.10 ; rm -rf libhal )
-( cd usr/doc/hal-0.5.10 ; ln -sf ../../share/gtk-doc/html/libhal libhal )
-( cd usr/doc/hal-0.5.10 ; rm -rf libhal-storage )
-( cd usr/doc/hal-0.5.10 ; ln -sf ../../share/gtk-doc/html/libhal-storage libhal-storage )
+( cd usr/doc/hal-0.5.11 ; rm -rf libhal-storage )
+( cd usr/doc/hal-0.5.11 ; ln -sf ../../share/gtk-doc/html/libhal-storage libhal-storage )
+( cd usr/doc/hal-0.5.11 ; rm -rf libhal )
+( cd usr/doc/hal-0.5.11 ; ln -sf ../../share/gtk-doc/html/libhal libhal )
